@@ -20,7 +20,6 @@
  * @author     Daniel Convissor <danielc@php.net>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    CVS: $Id$
  * @link       http://pear.php.net/package/DB
  */
 
@@ -42,7 +41,7 @@ require_once 'PEAR.php';
  * @author     Daniel Convissor <danielc@php.net>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    Release: 1.11.0
+ * @version    Release: 1.12.2
  * @link       http://pear.php.net/package/DB
  */
 class DB_common extends PEAR
@@ -315,6 +314,7 @@ class DB_common extends PEAR
      *   + odbc(db2)
      *   + pgsql
      *   + sqlite
+     *   + sqlite3
      *   + sybase (must execute <kbd>set quoted_identifier on</kbd> sometime
      *     prior to use)
      *
@@ -417,6 +417,10 @@ class DB_common extends PEAR
      *        (<kbd>INTEGER</kbd>)
      *      </li>
      *      <li>
+     *        <kbd>sqlite3</kbd> -> <samp>1/0</samp>
+     *        (<kbd>INTEGER</kbd>)
+     *      </li>
+     *      <li>
      *        <kbd>sybase</kbd> -> <samp>1/0</samp>
      *        (<kbd>TINYINT(1)</kbd>)
      *      </li>
@@ -641,6 +645,7 @@ class DB_common extends PEAR
      * + mysql
      * + mysqli
      * + sqlite
+     * + sqlite3
      *
      *
      * <samp>DB_PORTABILITY_NUMROWS</samp>
@@ -720,6 +725,7 @@ class DB_common extends PEAR
                         case 'mysql':
                         case 'mysqli':
                         case 'sqlite':
+                        case 'sqlite3':
                             $this->options['portability'] =
                                     DB_PORTABILITY_DELETE_COUNT;
                             break;
@@ -1808,6 +1814,23 @@ class DB_common extends PEAR
         return $this->raiseError(DB_ERROR_NOT_CAPABLE);
     }
 
+    // }}}
+    // {{{ lastId()
+
+    /**
+     * Returns the row ID of the most recent INSERT into the database
+     *
+     * @param string  $link_identifier  DBMS link identifier
+     *
+     * @return int the row ID of the most recent INSERT into the database.
+     *             If no successful INSERTs into rowid tables have ever
+     *             occurred on this database connection then returns 0.
+     */
+    function lastId($link_identifier = null)
+    {
+        return $this->raiseError(DB_ERROR_NOT_CAPABLE);
+    }
+
     // }}}
     // {{{ createSequence()
 
