@@ -20,7 +20,6 @@
  * @author     Daniel Convissor <danielc@php.net>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    CVS: $Id$
  * @link       http://pear.php.net/package/DB
  */
 
@@ -44,7 +43,7 @@ require_once 'DB/common.php';
  * @author     Daniel Convissor <danielc@php.net>
  * @copyright  1997-2007 The PHP Group
  * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
- * @version    Release: 1.11.0
+ * @version    Release: 1.12.2
  * @link       http://pear.php.net/package/DB
  */
 class DB_odbc extends DB_common
@@ -331,7 +330,7 @@ class DB_odbc extends DB_common
             return null;
         }
         if ($fetchmode !== DB_FETCHMODE_ORDERED) {
-            for ($i = 0; $i < count($arr); $i++) {
+            for ($i = 0, $iMax = count($arr); $i < $iMax; $i++) {
                 $colName = @odbc_field_name($result, $i+1);
                 $a[$colName] = $arr[$i];
             }
@@ -502,7 +501,7 @@ class DB_odbc extends DB_common
         $repeat = 0;
         do {
             $this->pushErrorHandling(PEAR_ERROR_RETURN);
-            $result = $this->query("update ${seqname} set id = id + 1");
+            $result = $this->query("update {$seqname} set id = id + 1");
             $this->popErrorHandling();
             if ($ondemand && DB::isError($result) &&
                 $result->getCode() == DB_ERROR_NOSUCHTABLE) {
@@ -513,7 +512,7 @@ class DB_odbc extends DB_common
                 if (DB::isError($result)) {
                     return $this->raiseError($result);
                 }
-                $result = $this->query("insert into ${seqname} (id) values(0)");
+                $result = $this->query("insert into {$seqname} (id) values(0)");
             } else {
                 $repeat = 0;
             }
@@ -523,7 +522,7 @@ class DB_odbc extends DB_common
             return $this->raiseError($result);
         }
 
-        $result = $this->query("select id from ${seqname}");
+        $result = $this->query("select id from {$seqname}");
         if (DB::isError($result)) {
             return $result;
         }
